==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDFIELDLOVSETTINGS.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="LOV_TYPE" type="{http://schemas.datastream.net/MP_fields}CODE8_Type"/>
 *         &lt;element name="LOV_VALIDATE" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *         &lt;element name="LOV_ENTITY" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "lov_TYPE",
    "lov_VALIDATE",
    "lov_ENTITY"
})
@XmlRootElement(name = "USERDEFINEDFIELDLOVSETTINGS")
public class USERDEFINEDFIELDLOVSETTINGS {

    @XmlElement(name = "LOV_TYPE", required = true)
    protected String lov_TYPE;
    @XmlElement(name = "LOV_VALIDATE", required = true)
    protected String lov_VALIDATE;
    @XmlElement(name = "LOV_ENTITY")
    protected String lov_ENTITY;

    /**
     * Obtient la valeur de la propriété lov_TYPE.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOV_TYPE() {
        return lov_TYPE;
    }

    /**
     * Définit la valeur de la propriété lov_TYPE.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOV_TYPE(String value) {
        this.lov_TYPE = value;
    }

    /**
     * Obtient la valeur de la propriété lov_VALIDATE.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOV_VALIDATE() {
        return lov_VALIDATE;
    }

    /**
     * Définit la valeur de la propriété lov_VALIDATE.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOV_VALIDATE(String value) {
        this.lov_VALIDATE = value;
    }

    /**
     * Obtient la valeur de la propriété lov_ENTITY.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOV_ENTITY() {
        return lov_ENTITY;
    }

    /**
     * Définit la valeur de la propriété lov_ENTITY.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOV_ENTITY(String value) {
        this.lov_ENTITY = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/USERDEFINEDFIELDLOVSETTINGS.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="LOV_TYPE" type="{http://schemas.datastream.net/MP_fields}CODE8_Type"/>
 *         &lt;element name="LOV_VALIDATE" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *         &lt;element name="LOV_ENTITY" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "lov_TYPE",
    "lov_VALIDATE",
    "lov_ENTITY"
})
@XmlRootElement(name = "USERDEFINEDFIELDLOVSETTINGS")
public class USERDEFINEDFIELDLOVSETTINGS {

    @XmlElement(name = "LOV_TYPE", required = true)
    protected String lov_TYPE;
    @XmlElement(name = "LOV_VALIDATE", required = true)
    protected String lov_VALIDATE;
    @XmlElement(name = "LOV_ENTITY")
    protected String lov_ENTITY;

    /**
     * Gets the value of the lov_TYPE property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOV_TYPE() {
        return lov_TYPE;
    }

    /**
     * Sets the value of the lov_TYPE property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOV_TYPE(String value) {
        this.lov_TYPE = value;
    }

    /**
     * Gets the value of the lov_VALIDATE property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOV_VALIDATE() {
        return lov_VALIDATE;
    }

    /**
     * Sets the value of the lov_VALIDATE property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOV_VALIDATE(String value) {
        this.lov_VALIDATE = value;
    }

    /**
     * Gets the value of the lov_ENTITY property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOV_ENTITY() {
        return lov_ENTITY;
    }

    /**
     * Sets the value of the lov_ENTITY property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOV_ENTITY(String value) {
        this.lov_ENTITY = value;
    }

}
